import os

base_metacfg = """from metasim.cfg.checkers.checkers import DetectedChecker
from metasim.cfg.checkers.detectors import RelativeBboxDetector
from metasim.cfg.objects import RigidObjMetaCfg
from metasim.constants import PhysicStateType
from metasim.utils import configclass

from ..maniskill_task_metacfg import ManiskillTaskMetaCfg


@configclass
class PegInsertionSide{i_case}MetaCfg(ManiskillTaskMetaCfg):
    episode_length = 250
    objects = [
        # The hole on the base is slightly enlarged to reduce the difficulty due to the dynamics gap
        RigidObjMetaCfg(
            name="box",
            filepath="data_isaaclab/assets/maniskill2/peg_insertion/usd/base_{i_case}.usd",
            physics=PhysicStateType.GEOM,
            fix_base_link=True,
        ),
        RigidObjMetaCfg(
            name="stick",
            filepath="data_isaaclab/assets/maniskill2/peg_insertion/usd/stick_{i_case}.usd",
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data/source_data/maniskill2/rigid_body/PegInsertionSide-v0/trajs/trajectory-franka-{i_case}_v2.pkl"

    checker = DetectedChecker(
        obj_name="stick",
        detector=RelativeBboxDetector(
            base_obj_name="box",
            relative_quat=[1, 0, 0, 0],
            relative_pos=[-0.05, 0, 0],
            checker_lower=[-0.05, -0.1, -0.1],
            checker_upper=[0.05, 0.1, 0.1],
        ),
    )
"""

# For the checker: The hole on the base are at different positions for different asset.
# The core logic is to check the stick position along the x-axis, relative to the base.

# The stick is slightly shrinked for the peg insertion task.

n_case = 1000

init_script_content = ""
os.makedirs("metasim/cfg/tasks/maniskill/peg_insertion_side", exist_ok=True)
for i_case in range(n_case):
    with open(f"metasim/cfg/tasks/maniskill/peg_insertion_side/peg_insertion_side_{i_case}_metacfg.py", "w") as f:
        f.write(base_metacfg.format(i_case=i_case))
    init_script_content += f"from .peg_insertion_side_{i_case}_metacfg import PegInsertionSide{i_case}MetaCfg\n"

with open("metasim/cfg/tasks/maniskill/peg_insertion_side/__init__.py", "w") as f:
    f.write(init_script_content)



import math

import torch
from loguru import logger as log

from metasim.cfg.checkers import JointPosChecker
from metasim.cfg.objects import ArticulationObjMetaCfg
from metasim.utils import configclass

from .rlbench_task_metacfg import RLBenchTaskMetaCfg


@configclass
class CloseBoxMetaCfg(RLBenchTaskMetaCfg):
    episode_length = 250
    objects = [
        ArticulationObjMetaCfg(
            name="box_base",
            fix_base_link=True,
            filepath="roboverse_data/assets/rlbench/close_box/box_base/usd/box_base.usd",
            urdf_path="roboverse_data/assets/rlbench/close_box/box_base/urdf/box_base_unique.urdf",
            mjcf_path="roboverse_data/assets/rlbench/close_box/box_base/mjcf/box_base_unique.mjcf",
        ),
    ]
    traj_filepath = "roboverse_data/trajs/rlbench/close_box/v2"
    checker = JointPosChecker(
        obj_name="box_base",
        joint_name="box_joint",
        mode="le",
        radian_threshold=-14 / 180 * math.pi,
    )

    def reward_fn(self, states):
        # HACK: metasim_body_panda_hand may not be universal across all robots
        try:
            ee_poses = torch.stack([state["metasim_body_panda_hand"]["pos"] for state in states])
        except KeyError as e:
            log.error(f"KeyError: {e}")
            ee_poses = torch.zeros(len(states), 3)
        distance = torch.norm(ee_poses, dim=-1)
        return -distance



from __future__ import annotations

import os

from loguru import logger as log

from metasim.cfg.robots.base_robot_metacfg import BaseRobotMetaCfg
from metasim.cfg.tasks.base_task_metacfg import BaseTaskMetaCfg
from metasim.sim.base import BaseSimHandler

from .demo_util_v1 import get_traj_v1
from .demo_util_v2 import get_traj_v2


def get_traj(task: BaseTaskMetaCfg, robot: BaseRobotMetaCfg, handler: BaseSimHandler | None = None):
    if task.traj_filepath.find("v2") != -1:
        log.info("Reading trajectory using v2 data format")
        if os.path.exists(task.traj_filepath):
            return get_traj_v2(task, robot)
        else:
            raise FileNotFoundError(
                "The trajectory file does not exist, please check the path or convert the trajectory file to v2 format"
            )
    else:
        log.warning("Reading trajectory using v1 data format, which is deprecated")
        assert handler is not None, "Handler is required for v1 data format"
        return get_traj_v1(task, robot, handler)



from __future__ import annotations

from dataclasses import MISSING
from typing import Literal

import torch
from loguru import logger as log

from metasim.cfg.objects import BaseObjMetaCfg
from metasim.utils.configclass import configclass
from metasim.utils.math import euler_xyz_from_quat, matrix_from_quat, quat_from_matrix
from metasim.utils.tensor_util import tensor_to_str

from .base_checker import BaseChecker
from .detectors import BaseDetector

try:
    from metasim.sim.base import BaseSimHandler
except:
    pass


@configclass
class DetectedChecker(BaseChecker):
    obj_name: str = MISSING
    obj_subpath: str | None = None
    detector: BaseDetector = MISSING
    ignore_if_first_check_success: bool = False

    def reset(self, handler: BaseSimHandler, env_ids: list[int] | None = None):
        self._first_check = torch.ones(handler.num_envs, dtype=torch.bool)  # True
        self._ignore = torch.zeros(handler.num_envs, dtype=torch.bool)  # False
        self.detector.reset(handler, env_ids=env_ids)

    def check(self, handler: BaseSimHandler) -> torch.BoolTensor:
        success = self.detector.is_detected(handler, self.obj_name, self.obj_subpath)
        if self.ignore_if_first_check_success:
            self._ignore[self._first_check & success] = True
        self._first_check[self._first_check] = False

        success[self._ignore] = False
        return success

    def get_debug_viewers(self) -> list[BaseObjMetaCfg]:
        return self.detector.get_debug_viewers()


@configclass
class JointPosChecker(BaseChecker):
    obj_name: str = MISSING
    joint_name: str = MISSING
    mode: Literal["ge", "le"] = MISSING
    radian_threshold: float = MISSING

    def check(self, handler: BaseSimHandler) -> torch.BoolTensor:
        dof_pos = handler.get_dof_pos(self.obj_name, self.joint_name)
        if self.mode == "ge":
            return dof_pos >= self.radian_threshold
        elif self.mode == "le":
            return dof_pos <= self.radian_threshold
        else:
            raise ValueError(f"Invalid mode: {self.mode}")

    def get_debug_viewers(self) -> list[BaseObjMetaCfg]:
        return []


@configclass
class JointPosShiftChecker(BaseChecker):
    """
    Check if the joint with `joint_name` of the object with `obj_name` was moved more than `threshold` units.
    - `threshold` is negative for moving towards the negative direction and positive for moving towards the positive direction.
    """

    obj_name: str = MISSING
    joint_name: str = MISSING
    threshold: float = MISSING

    def reset(self, handler: BaseSimHandler, env_ids: list[int] | None = None):
        if env_ids is None:
            env_ids = list(range(handler.num_envs))

        if not hasattr(self, "init_joint_pos"):
            self.init_joint_pos = torch.zeros(handler.num_envs, dtype=torch.float32)

        self.init_joint_pos[env_ids] = handler.get_dof_pos(self.obj_name, self.joint_name, env_ids=env_ids)

    def check(self, handler: BaseSimHandler) -> torch.BoolTensor:
        cur_joint_pos = handler.get_dof_pos(self.obj_name, self.joint_name)
        joint_pos_diff = cur_joint_pos - self.init_joint_pos

        log.debug(f"Joint {self.joint_name} of object {self.obj_name} moved {tensor_to_str(joint_pos_diff)} units")

        if self.threshold > 0:
            return joint_pos_diff >= self.threshold
        else:
            return joint_pos_diff <= self.threshold


@configclass
class RotationShiftChecker(BaseChecker):
    """
    Check if the object with `obj_name` was rotated more than `radian_threshold` radians around the given `axis`.
    - `radian_threshold` is negative for clockwise rotations and positive for counter-clockwise rotations.
    - `radian_threshold` should be in the range of [-pi, pi].
    - `axis` should be one of "x", "y", "z". default is "z".
    """

    ## ref: https://github.com/mees/calvin_env/blob/c7377a6485be43f037f4a0b02e525c8c6e8d24b0/calvin_env/envs/tasks.py#L54
    obj_name: str = MISSING
    radian_threshold: float = MISSING
    axis: Literal["x", "y", "z"] = "z"

    def reset(self, handler: BaseSimHandler, env_ids: list[int] | None = None):
        if env_ids is None:
            env_ids = list(range(handler.num_envs))

        if not hasattr(self, "init_quat"):
            self.init_quat = torch.zeros(handler.num_envs, 4, dtype=torch.float32)

        self.init_quat[env_ids] = handler.get_rot(self.obj_name, env_ids=env_ids)

    def check(self, handler: BaseSimHandler) -> torch.BoolTensor:
        cur_quat = handler.get_rot(self.obj_name)
        init_rot_mat = matrix_from_quat(self.init_quat)
        cur_rot_mat = matrix_from_quat(cur_quat)
        rot_diff = torch.matmul(cur_rot_mat, init_rot_mat.transpose(-1, -2))
        x, y, z = euler_xyz_from_quat(quat_from_matrix(rot_diff))
        v = {"x": x, "y": y, "z": z}[self.axis]

        ## Normalize the rotation angle to be within [-pi, pi]
        v[v > torch.pi] -= 2 * torch.pi
        v[v < -torch.pi] += 2 * torch.pi
        assert ((v >= -torch.pi) & (v <= torch.pi)).all()

        log.debug(f"Object {self.obj_name} rotated {tensor_to_str(v / torch.pi * 180)} degrees around {self.axis}-axis")

        if self.radian_threshold > 0:
            return v >= self.radian_threshold
        else:
            return v <= self.radian_threshold


@configclass
class PositionShiftChecker(BaseChecker):
    """
    Check if the object with `obj_name` was moved more than `distance` meters in given `axis`.
    - `distance` is negative for moving towards the negative direction and positive for moving towards the positive direction.
    - `max_distance` is the maximum distance the object can move.
    - `axis` should be one of "x", "y", "z".
    """

    obj_name: str = MISSING
    distance: float = MISSING
    bounding_distance: float = 1e2
    axis: Literal["x", "y", "z"] = MISSING

    def reset(self, handler: BaseSimHandler, env_ids: list[int] | None = None):
        if env_ids is None:
            env_ids = list(range(handler.num_envs))

        if not hasattr(self, "init_pos"):
            self.init_pos = torch.zeros(handler.num_envs, 3, dtype=torch.float32)

        tmp = handler.get_pos(self.obj_name, env_ids=env_ids)
        assert tmp.shape == (len(env_ids), 3)
        self.init_pos[env_ids] = tmp

    def check(self, handler: BaseSimHandler) -> torch.BoolTensor:
        cur_pos = handler.get_pos(self.obj_name)
        if torch.isnan(cur_pos).any():
            log.debug(f"Object {self.obj_name} moved to nan position")
            return torch.ones(cur_pos.shape[0], dtype=torch.bool)
        dim = {"x": 0, "y": 1, "z": 2}[self.axis]
        dis_diff = cur_pos - self.init_pos
        dim_diff = dis_diff[:, dim]
        tot_dis = torch.norm(dis_diff, dim=-1)
        log.debug(f"Object {self.obj_name} moved {tensor_to_str(dim_diff)} meters in {self.axis} direction")
        if self.distance > 0:
            return (dim_diff >= self.distance) * (tot_dis <= self.bounding_distance)
        else:
            return dim_diff <= self.distance


@configclass
class SlideChecker(BaseChecker):
    def check(self, handler: BaseSimHandler) -> torch.BoolTensor:
        from metasim.utils.h1_utils import torso_upright

        states = handler.get_states()
        terminated = []
        for state in states:
            if torso_upright(state, handler._robot.name) < 0.6:
                terminated.append(True)
            else:
                terminated.append(False)
        return torch.tensor(terminated)


@configclass
class WalkChecker(BaseChecker):
    def check(self, handler: BaseSimHandler) -> torch.BoolTensor:
        from metasim.utils.h1_utils import z_height

        states = handler.get_states()
        terminated = []
        for state in states:
            if z_height(state, handler._robot.name) < 0.2:
                terminated.append(True)
            else:
                terminated.append(False)
        return torch.tensor(terminated)


@configclass
class StandChecker(WalkChecker):
    pass


@configclass
class RunChecker(WalkChecker):
    pass


@configclass
class CrawlChecker(BaseChecker):
    def check(self, handler: BaseSimHandler) -> torch.BoolTensor:
        states = handler.get_states()
        terminated = [False] * len(states)
        return torch.tensor(terminated)


@configclass
class HurdleChecker(BaseChecker):
    def check(self, handler: BaseSimHandler) -> torch.BoolTensor:
        states = handler.get_states()
        terminated = [False] * len(states)
        return torch.tensor(terminated)


@configclass
class MazeChecker(BaseChecker):
    def check(self, handler: BaseSimHandler) -> torch.BoolTensor:
        from metasim.utils.h1_utils import z_height

        states = handler.get_states()
        terminated = []
        for state in states:
            if z_height(state, handler._robot.name) < 0.2:
                terminated.append(True)
            else:
                terminated.append(False)
        return torch.tensor(terminated)


@configclass
class PoleChecker(BaseChecker):
    def check(self, handler: BaseSimHandler) -> torch.BoolTensor:
        from metasim.utils.h1_utils import z_height

        states = handler.get_states()
        terminated = []
        for state in states:
            if z_height(state, handler._robot.name) < 0.6:
                terminated.append(True)
            else:
                terminated.append(False)
        return torch.tensor(terminated)


@configclass
class SitChecker(BaseChecker):
    def check(self, handler: BaseSimHandler) -> torch.BoolTensor:
        from metasim.utils.h1_utils import z_height

        states = handler.get_states()
        terminated = []
        for state in states:
            if z_height(state, handler._robot.name) < 0.5:
                terminated.append(True)
            else:
                terminated.append(False)
        return torch.tensor(terminated)


@configclass
class BalanceChecker(BaseChecker):
    def check(self, handler: BaseSimHandler) -> torch.BoolTensor:
        from metasim.utils.h1_utils import z_height

        states = handler.get_states()
        terminated = []
        for state in states:
            if z_height(state, handler._robot.name) < 0.8:
                terminated.append(True)
            else:
                terminated.append(False)
        return torch.tensor(terminated)


@configclass
class StairChecker(BaseChecker):
    def check(self, handler: BaseSimHandler) -> torch.BoolTensor:
        from metasim.utils.h1_utils import torso_upright

        states = handler.get_states()
        terminated = []
        for state in states:
            if torso_upright(state, handler._robot.name) < 0.1:
                terminated.append(True)
            else:
                terminated.append(False)
        return torch.tensor(terminated)


@configclass
class PushChecker(BaseChecker):
    def check(self, handler: BaseSimHandler) -> torch.BoolTensor:
        states = handler.get_states()
        terminated = []

        for state in states:
            # Get box position
            box_pos = state["object"]["pos"]

            # Get destination position
            dest_pos = state["destination"]["pos"]

            # Calculate distance between box and destination
            dgoal = torch.norm(box_pos - dest_pos)

            # Terminate when dgoal < 0.05 (success)
            if dgoal < 0.05:
                terminated.append(True)
            else:
                terminated.append(False)

        return torch.tensor(terminated)



from metasim.cfg.checkers import DetectedChecker, Relative3DSphereDetector
from metasim.cfg.objects import RigidObjMetaCfg
from metasim.constants import BenchmarkType, PhysicStateType, TaskType
from metasim.utils import configclass

from .base_task_metacfg import BaseTaskMetaCfg


@configclass
class BinPickMetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.METAWORLD
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 500
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="data_isaaclab/assets/metaworld/bin_pick/obj.usd",
            physics=PhysicStateType.RIGIDBODY,
        ),
        RigidObjMetaCfg(
            name="binA",
            filepath="data_isaaclab/assets/metaworld/bin_pick/binA.usd",
            physics=PhysicStateType.GEOM,
        ),
        RigidObjMetaCfg(
            name="binB",
            filepath="data_isaaclab/assets/metaworld/bin_pick/binB.usd",
            physics=PhysicStateType.GEOM,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/metaworld/rigid_body/bin_pick_v2.pkl"
    checker = DetectedChecker(
        obj_name="obj",
        detector=Relative3DSphereDetector(
            base_obj_name="binB",
            relative_pos=[0.0, 0.0, 0.0],
            radius=0.05,
        ),
    )



from __future__ import annotations

from metasim.utils import configclass

from .base_robot_metacfg import BaseActuatorMetaCfg, BaseRobotMetaCfg


@configclass
class H12WithoutHandMetaCfg(BaseRobotMetaCfg):
    name: str = "h1_2_without_hand"
    num_joints: int = 27
    filepath: str = "data_isaaclab/robots/unitree/H1-2_without_hand.usd"
    enabled_gravity: bool = True  # ! critical
    freejoint: bool = True
    enabled_self_collisions: bool = False
    actuators: dict[str, BaseActuatorMetaCfg] = {
        "torso_joint": BaseActuatorMetaCfg(),
        "left_shoulder_pitch_joint": BaseActuatorMetaCfg(),
        "right_shoulder_pitch_joint": BaseActuatorMetaCfg(),
        "left_hip_yaw_joint": BaseActuatorMetaCfg(),
        "right_hip_yaw_joint": BaseActuatorMetaCfg(),
        "left_shoulder_roll_joint": BaseActuatorMetaCfg(),
        "right_shoulder_roll_joint": BaseActuatorMetaCfg(),
        "left_hip_pitch_joint": BaseActuatorMetaCfg(),
        "right_hip_pitch_joint": BaseActuatorMetaCfg(),
        "left_shoulder_yaw_joint": BaseActuatorMetaCfg(),
        "right_shoulder_yaw_joint": BaseActuatorMetaCfg(),
        "left_hip_roll_joint": BaseActuatorMetaCfg(),
        "right_hip_roll_joint": BaseActuatorMetaCfg(),
        "left_elbow_pitch_joint": BaseActuatorMetaCfg(),
        "right_elbow_pitch_joint": BaseActuatorMetaCfg(),
        "left_knee_joint": BaseActuatorMetaCfg(),
        "right_knee_joint": BaseActuatorMetaCfg(),
        "left_elbow_roll_joint": BaseActuatorMetaCfg(),
        "right_elbow_roll_joint": BaseActuatorMetaCfg(),
        "left_ankle_pitch_joint": BaseActuatorMetaCfg(),
        "right_ankle_pitch_joint": BaseActuatorMetaCfg(),
        "left_wrist_pitch_joint": BaseActuatorMetaCfg(),
        "right_wrist_pitch_joint": BaseActuatorMetaCfg(),
        "left_ankle_roll_joint": BaseActuatorMetaCfg(),
        "right_ankle_roll_joint": BaseActuatorMetaCfg(),
        "left_wrist_yaw_joint": BaseActuatorMetaCfg(),
        "right_wrist_yaw_joint": BaseActuatorMetaCfg(),
    }
    joint_limits: dict[str, tuple[float, float]] = {
        "torso_joint": (-2.3500, 2.3500),
        "left_shoulder_pitch_joint": (-3.1400, 1.5700),
        "right_shoulder_pitch_joint": (-3.1400, 1.5700),
        "left_hip_yaw_joint": (-0.4300, 0.4300),
        "right_hip_yaw_joint": (-0.4300, 0.4300),
        "left_shoulder_roll_joint": (-0.3800, 3.4000),
        "right_shoulder_roll_joint": (-3.4000, 0.3800),
        "left_hip_pitch_joint": (-3.1400, 2.5000),
        "right_hip_pitch_joint": (-3.1400, 2.5000),
        "left_shoulder_yaw_joint": (-2.6600, 3.0100),
        "right_shoulder_yaw_joint": (-3.0100, 2.6600),
        "left_hip_roll_joint": (-0.4300, 3.1400),
        "right_hip_roll_joint": (-3.1400, 0.4300),
        "left_elbow_pitch_joint": (-0.9500, 3.1800),
        "right_elbow_pitch_joint": (-0.9500, 3.1800),
        "left_knee_joint": (-0.2600, 2.0500),
        "right_knee_joint": (-0.2600, 2.0500),
        "left_elbow_roll_joint": (-3.0100, 2.7500),
        "right_elbow_roll_joint": (-2.7500, 3.0100),
        "left_ankle_pitch_joint": (-0.8973, 0.5236),
        "right_ankle_pitch_joint": (-0.8973, 0.5236),
        "left_wrist_pitch_joint": (-0.4700, 0.4700),
        "right_wrist_pitch_joint": (-0.4700, 0.4700),
        "left_ankle_roll_joint": (-0.2618, 0.2618),
        "right_ankle_roll_joint": (-0.2618, 0.2618),
        "left_wrist_yaw_joint": (-1.2700, 1.2700),
        "right_wrist_yaw_joint": (-1.2700, 1.2700),
    }



from __future__ import annotations

import os
from glob import glob

import torch
from loguru import logger as log

from metasim.cfg.robots.base_robot_metacfg import BaseRobotMetaCfg
from metasim.cfg.tasks.base_task_metacfg import BaseTaskMetaCfg

from .loader import load_traj_file


def get_traj_v2(task: BaseTaskMetaCfg, robot: BaseRobotMetaCfg):
    ## Load trajectory data
    assert os.path.exists(task.traj_filepath)
    if os.path.isfile(task.traj_filepath):
        assert (
            task.traj_filepath.endswith("_v2.pkl")
            or task.traj_filepath.endswith("_v2.pkl.gz")
            or task.traj_filepath.endswith("_v2.json")
            or task.traj_filepath.endswith("_v2.yaml")
        )
        data = load_traj_file(task.traj_filepath)[robot.name]
    else:
        assert task.traj_filepath.find("v2") != -1
        paths = glob(os.path.join(task.traj_filepath, f"{robot.name}_v2.*"))
        assert len(paths) >= 1
        path = paths[0]
        log.info(f"Loading trajectory from {path}")
        data = load_traj_file(path)[robot.name]

    ## Parse initial states
    if "init_state" in data[0]:
        init_states = [traj["init_state"] for traj in data]
    else:
        raise ValueError("No init_state found in the trajectory data")
    for demo_idx, init_state in enumerate(init_states):
        for obj_name in init_state:
            init_states[demo_idx][obj_name]["pos"] = torch.tensor(init_states[demo_idx][obj_name]["pos"])
            init_states[demo_idx][obj_name]["rot"] = torch.tensor(init_states[demo_idx][obj_name]["rot"])

    ## Parse actions
    if "actions" in data[0]:
        all_actions = [traj["actions"] for traj in data]
    else:
        log.error("No actions found in the trajectory data")
        all_actions = None

    ## Parse states
    if "states" in data[0] and data[0]["states"] is not None:
        all_states = [traj["states"] for traj in data]
        for demo_idx, states in enumerate(all_states):
            for step_idx, state in enumerate(states):
                for obj_name in state:
                    all_states[demo_idx][step_idx][obj_name]["pos"] = torch.tensor(state[obj_name]["pos"])
                    all_states[demo_idx][step_idx][obj_name]["rot"] = torch.tensor(state[obj_name]["rot"])
    else:
        log.error("No states found in the trajectory data")
        all_states = None

    return init_states, all_actions, all_states



from metasim.cfg.objects import PrimitiveCubeMetaCfg, RigidObjMetaCfg
from metasim.constants import PhysicStateType
from metasim.utils import configclass

from .rlbench_task_metacfg import RLBenchTaskMetaCfg


@configclass
class PutToiletRollOnStandMetaCfg(RLBenchTaskMetaCfg):
    episode_length = 200
    traj_filepath = "roboverse_data/trajs/rlbench/put_toilet_roll_on_stand/v2"
    objects = [
        RigidObjMetaCfg(
            name="toilet_roll_visual",
            filepath="roboverse_data/assets/rlbench/put_toilet_roll_on_stand/toilet_roll_visual/usd/toilet_roll_visual.usd",
            physics=PhysicStateType.RIGIDBODY,
        ),
        RigidObjMetaCfg(
            name="stand_base",
            filepath="roboverse_data/assets/rlbench/put_toilet_roll_on_stand/stand_base/usd/stand_base.usd",
            physics=PhysicStateType.RIGIDBODY,
        ),
        PrimitiveCubeMetaCfg(
            name="toilet_roll_box",
            size=[0.1, 0.1, 0.1],
            color=[0.85, 0.85, 0.85],
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    # TODO: add checker



from __future__ import annotations

from dataclasses import MISSING

import gymnasium as gym
import torch

from metasim.cfg.checkers import BaseChecker
from metasim.cfg.objects import BaseObjMetaCfg
from metasim.constants import BenchmarkType, TaskType
from metasim.types import EnvState
from metasim.utils import configclass


## TODO: move this to object definition
@configclass
class SiteMetaCfg:
    base_name: str = MISSING
    relative_pos: list[float] = MISSING
    relative_quat: list[float] = MISSING


@configclass
class BaseTaskMetaCfg:
    decimation: int = 3
    episode_length: int = MISSING
    objects: list[BaseObjMetaCfg] = MISSING
    traj_filepath: str = MISSING
    source_benchmark: BenchmarkType = MISSING
    task_type: TaskType = MISSING
    checker: BaseChecker = BaseChecker()
    can_tabletop: bool = False
    reward_functions: list[callable[[list[EnvState], str | None], torch.FloatTensor]] = MISSING
    reward_weights: list[float] = MISSING


@configclass
class BaseRLTaskMetaCfg(BaseTaskMetaCfg):
    # action_space: gym.spaces.Space, can be inferenced from robot (joint_limits)
    observation_space: gym.spaces.Space = MISSING
    observation_function: callable[[list[EnvState]], torch.FloatTensor] = MISSING  # [dummy_obs]

    reward_range: tuple[float, float] = (-float("inf"), float("inf"))



import os

from huggingface_hub import HfApi, HfFileSystem, hf_hub_download
from loguru import logger as log

REPO_ID = "RoboVerseOrg/roboverse_data"
LOCAL_DIR = "roboverse_data"

hf_api = HfApi()
hf_fs = HfFileSystem()


def _check_repo_access():
    if not hf_api.repo_exists(REPO_ID, repo_type="dataset", token=True):
        raise Exception(
            "Cannot access the huggingface repository. Please check your token is correctly set and try again."
            "\nTo generate a token, go to https://huggingface.co/settings/tokens. A token with read access is"
            " enough."
            "\nTo set your token, run `huggingface-cli login` or `export HF_TOKEN=<your_token>`."
            "\nIf one way doesn't work, please try the other way. It is very likely a huggingface bug."
        )


def check_and_download(filepath: str):
    """
    Args:
        filepath: the filepath to check and download. It should a existing file in the local directory. It should start with `LOCAL_DIR`.
    """
    local_exists = os.path.exists(filepath)
    hf_exists = hf_fs.exists(os.path.join("datasets", REPO_ID, os.path.relpath(filepath, LOCAL_DIR)))

    if local_exists:
        ## In this case, the runner is a developer who has the file in their local machine.
        if hf_exists:
            return
        else:
            _check_repo_access()
            log.warning(f"Please upload the file {filepath} to the huggingface dataset!")
            return
    else:
        ## In this case, we didn't find the file in the local directory, the circumstance is complicated.

        ## First, make sure we have the access to the repo
        _check_repo_access()

        ## Then, make sure the file exists in the huggingface dataset.
        if not hf_exists:
            raise Exception(
                f"File {filepath} neither exists in the local directory nor exists in the huggingface dataset. Please"
                " report this issue to the developers."
            )

        ## Also, we need to exclude a circumstance that a developer forgot to update the submodule.
        using_hf_git = os.path.exists(os.path.join(LOCAL_DIR, ".git"))
        if using_hf_git:
            raise Exception(
                "Please update the roboverse_data to the latest version, by running `cd roboverse_data && git pull`."
            )

        ## Finally, download the file from the huggingface dataset.
        try:
            hf_hub_download(
                repo_id=REPO_ID,
                filename=os.path.relpath(filepath, LOCAL_DIR),
                repo_type="dataset",
                token=True,
                local_dir=LOCAL_DIR,
            )
        except Exception as e:
            raise e



## TODO:
## 1. The checker is not same as the original one
##    The original one checks if the cube is near the given target position
##    The current one checks if the cube is lifted up 0.1 meters

from metasim.cfg.checkers import PositionShiftChecker
from metasim.cfg.objects import PrimitiveCubeMetaCfg
from metasim.constants import PhysicStateType
from metasim.utils import configclass

from .maniskill_task_metacfg import ManiskillTaskMetaCfg


@configclass
class PickCubeMetaCfg(ManiskillTaskMetaCfg):
    episode_length = 250
    objects = [
        PrimitiveCubeMetaCfg(
            name="cube",
            size=[0.04, 0.04, 0.04],
            mass=0.02,
            physics=PhysicStateType.RIGIDBODY,
            color=[1.0, 0.0, 0.0],
            mjcf_path="roboverse_data/assets/maniskill/cube/cube.mjcf",
        ),
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_cube/trajectory-unified-retarget_v2.pkl"
    checker = PositionShiftChecker(
        obj_name="cube",
        distance=0.1,
        axis="z",
    )



from metasim.cfg.checkers import PositionShiftChecker
from metasim.cfg.objects import RigidObjMetaCfg
from metasim.constants import PhysicStateType
from metasim.utils import configclass

from .maniskill_task_metacfg import ManiskillTaskMetaCfg


@configclass
class _PickSingleYcbBaseMetaCfg(ManiskillTaskMetaCfg):
    episode_length = 250
    checker = PositionShiftChecker(
        obj_name="obj",
        distance=0.075,
        axis="z",
    )


@configclass
class PickSingleYcbLegoDuploMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/073-g_lego_duplo/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/073-g_lego_duplo/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-073-g_lego_duplo_v2.pkl"


@configclass
class PickSingleYcbWoodBlockMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/036_wood_block/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/036_wood_block/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-036_wood_block_v2.pkl"


@configclass
class PickSingleYcbFlatScrewdriverMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/044_flat_screwdriver/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/044_flat_screwdriver/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-044_flat_screwdriver_v2.pkl"


@configclass
class PickSingleYcbExtraLargeClampMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/052_extra_large_clamp/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/052_extra_large_clamp/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-052_extra_large_clamp_v2.pkl"


@configclass
class PickSingleYcbForkMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/030_fork/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/030_fork/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-030_fork_v2.pkl"


@configclass
class PickSingleYcbCupsMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/065-j_cups/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/065-j_cups/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-065-j_cups_v2.pkl"


@configclass
class PickSingleYcbPowerDrillMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/035_power_drill/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/035_power_drill/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-035_power_drill_v2.pkl"


@configclass
class PickSingleYcbBananaMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/011_banana/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/011_banana/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-011_banana_v2.pkl"


@configclass
class PickSingleYcbMasterChefCanMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/002_master_chef_can/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/002_master_chef_can/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-002_master_chef_can_v2.pkl"


@configclass
class PickSingleYcbPhillipsScrewdriverMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/043_phillips_screwdriver/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/043_phillips_screwdriver/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-043_phillips_screwdriver_v2.pkl"


@configclass
class PickSingleYcbHammerMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/048_hammer/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/048_hammer/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-048_hammer_v2.pkl"


@configclass
class PickSingleYcbPadlockMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/038_padlock/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/038_padlock/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-038_padlock_v2.pkl"


@configclass
class PickSingleYcbOrangeMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/017_orange/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/017_orange/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-017_orange_v2.pkl"


@configclass
class PickSingleYcbRubiksCubeMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/077_rubiks_cube/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/077_rubiks_cube/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-077_rubiks_cube_v2.pkl"


@configclass
class PickSingleYcbSpatulaMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/033_spatula/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/033_spatula/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-033_spatula_v2.pkl"


@configclass
class PickSingleYcbToyAirplaneMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/072-e_toy_airplane/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/072-e_toy_airplane/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-072-e_toy_airplane_v2.pkl"


@configclass
class PickSingleYcbStrawberryMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/012_strawberry/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/012_strawberry/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-012_strawberry_v2.pkl"


@configclass
class PickSingleYcbLemonMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/014_lemon/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/014_lemon/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-014_lemon_v2.pkl"


@configclass
class PickSingleYcbNineHolePegTestMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/071_nine_hole_peg_test/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/071_nine_hole_peg_test/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-071_nine_hole_peg_test_v2.pkl"


@configclass
class PickSingleYcbDiceMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/062_dice/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/062_dice/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-062_dice_v2.pkl"


@configclass
class PickSingleYcbRacquetballMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/057_racquetball/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/057_racquetball/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-057_racquetball_v2.pkl"


@configclass
class PickSingleYcbBowlMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/024_bowl/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/024_bowl/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-024_bowl_v2.pkl"


@configclass
class PickSingleYcbTomatoSoupCanMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/005_tomato_soup_can/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/005_tomato_soup_can/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-005_tomato_soup_can_v2.pkl"


@configclass
class PickSingleYcbCrackerBoxMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/003_cracker_box/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/003_cracker_box/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-003_cracker_box_v2.pkl"


@configclass
class PickSingleYcbScissorsMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/037_scissors/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/037_scissors/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-037_scissors_v2.pkl"


@configclass
class PickSingleYcbPlumMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/018_plum/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/018_plum/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-018_plum_v2.pkl"


@configclass
class PickSingleYcbBleachCleanserMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/021_bleach_cleanser/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/021_bleach_cleanser/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-021_bleach_cleanser_v2.pkl"


@configclass
class PickSingleYcbMediumClampMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/050_medium_clamp/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/050_medium_clamp/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-050_medium_clamp_v2.pkl"


@configclass
class PickSingleYcbSpongeMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/026_sponge/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/026_sponge/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-026_sponge_v2.pkl"


@configclass
class PickSingleYcbPitcherBaseMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/019_pitcher_base/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/019_pitcher_base/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-019_pitcher_base_v2.pkl"


@configclass
class PickSingleYcbTennisBallMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/056_tennis_ball/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/056_tennis_ball/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-056_tennis_ball_v2.pkl"


@configclass
class PickSingleYcbColoredWoodBlocksMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/070-b_colored_wood_blocks/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/070-b_colored_wood_blocks/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-070-b_colored_wood_blocks_v2.pkl"


@configclass
class PickSingleYcbMugMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/025_mug/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/025_mug/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-025_mug_v2.pkl"


@configclass
class PickSingleYcbBaseballMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/055_baseball/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/055_baseball/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-055_baseball_v2.pkl"


@configclass
class PickSingleYcbGelatinBoxMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/009_gelatin_box/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/009_gelatin_box/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-009_gelatin_box_v2.pkl"


@configclass
class PickSingleYcbTunaFishCanMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/007_tuna_fish_can/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/007_tuna_fish_can/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-007_tuna_fish_can_v2.pkl"


@configclass
class PickSingleYcbLargeClampMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/051_large_clamp/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/051_large_clamp/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-051_large_clamp_v2.pkl"


@configclass
class PickSingleYcbPeachMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/015_peach/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/015_peach/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-015_peach_v2.pkl"


@configclass
class PickSingleYcbKnifeMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/032_knife/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/032_knife/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-032_knife_v2.pkl"


@configclass
class PickSingleYcbAppleMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/013_apple/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/013_apple/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-013_apple_v2.pkl"


@configclass
class PickSingleYcbMustardBottleMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/006_mustard_bottle/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/006_mustard_bottle/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-006_mustard_bottle_v2.pkl"


@configclass
class PickSingleYcbPearMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/016_pear/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/016_pear/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-016_pear_v2.pkl"


@configclass
class PickSingleYcbLargeMarkerMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/040_large_marker/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/040_large_marker/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-040_large_marker_v2.pkl"


@configclass
class PickSingleYcbAdjustableWrenchMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/042_adjustable_wrench/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/042_adjustable_wrench/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-042_adjustable_wrench_v2.pkl"


@configclass
class PickSingleYcbSoftballMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/054_softball/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/054_softball/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-054_softball_v2.pkl"


@configclass
class PickSingleYcbFoamBrickMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/061_foam_brick/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/061_foam_brick/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-061_foam_brick_v2.pkl"


@configclass
class PickSingleYcbSugarBoxMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/004_sugar_box/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/004_sugar_box/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-004_sugar_box_v2.pkl"


@configclass
class PickSingleYcbMarblesMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/063-b_marbles/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/063-b_marbles/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-063-b_marbles_v2.pkl"


@configclass
class PickSingleYcbPottedMeatCanMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/010_potted_meat_can/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/010_potted_meat_can/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-010_potted_meat_can_v2.pkl"


@configclass
class PickSingleYcbGolfBallMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/058_golf_ball/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/058_golf_ball/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-058_golf_ball_v2.pkl"


@configclass
class PickSingleYcbMiniSoccerBallMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/053_mini_soccer_ball/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/053_mini_soccer_ball/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-053_mini_soccer_ball_v2.pkl"


@configclass
class PickSingleYcbPuddingBoxMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/008_pudding_box/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/008_pudding_box/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-008_pudding_box_v2.pkl"


@configclass
class PickSingleYcbSpoonMetaCfg(_PickSingleYcbBaseMetaCfg):
    objects = [
        RigidObjMetaCfg(
            name="obj",
            filepath="roboverse_data/assets/maniskill/ycb/031_spoon/object_proc.usd",
            urdf_path="roboverse_data/assets/maniskill/ycb/031_spoon/model_scaled.urdf",
            physics=PhysicStateType.RIGIDBODY,
        )
    ]
    traj_filepath = "roboverse_data/trajs/maniskill/pick_single_ycb/trajectory-franka-031_spoon_v2.pkl"



from metasim.cfg.objects import PrimitiveCubeMetaCfg, RigidObjMetaCfg
from metasim.cfg.tasks.base_task_metacfg import BaseTaskMetaCfg
from metasim.constants import BenchmarkType, PhysicStateType, TaskType
from metasim.utils import configclass


@configclass
class OpensdorRotLyingFlatHardDrive39MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="hard drive",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f8de4975c0f54c1a97203c6a674f6a39/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f8de4975c0f54c1a97203c6a674f6a39_lying_flat/20240826-212202_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatHardDrive40MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="hard drive",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f8de4975c0f54c1a97203c6a674f6a39/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f8de4975c0f54c1a97203c6a674f6a39_lying_flat/20240826-212815_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatHardDrive41MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="hard drive",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f8de4975c0f54c1a97203c6a674f6a39/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f8de4975c0f54c1a97203c6a674f6a39_lying_flat/20240826-213021_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatHardDrive42MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="hard drive",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f8de4975c0f54c1a97203c6a674f6a39/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f8de4975c0f54c1a97203c6a674f6a39_lying_flat/20240826-213834_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatHardDrive43MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="hard drive",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f8de4975c0f54c1a97203c6a674f6a39/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f8de4975c0f54c1a97203c6a674f6a39_lying_flat/20240826-211311_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatHardDrive44MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="hard drive",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f8de4975c0f54c1a97203c6a674f6a39/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f8de4975c0f54c1a97203c6a674f6a39_lying_flat/20240826-213407_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBinder58MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="binder",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/78e016eeb0bf45d5bea47547128383a8/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/78e016eeb0bf45d5bea47547128383a8_lying_flat/20240826-213254_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBinder59MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="binder",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/78e016eeb0bf45d5bea47547128383a8/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/78e016eeb0bf45d5bea47547128383a8_lying_flat/20240826-215128_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBinder60MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="binder",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/78e016eeb0bf45d5bea47547128383a8/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/78e016eeb0bf45d5bea47547128383a8_lying_flat/20240826-213818_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBinder61MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="binder",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/78e016eeb0bf45d5bea47547128383a8/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/78e016eeb0bf45d5bea47547128383a8_lying_flat/20240826-215433_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBinder62MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="binder",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/78e016eeb0bf45d5bea47547128383a8/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/78e016eeb0bf45d5bea47547128383a8_lying_flat/20240826-215236_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBinder63MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="binder",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/78e016eeb0bf45d5bea47547128383a8/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/78e016eeb0bf45d5bea47547128383a8_lying_flat/20240826-213132_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBinder64MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="binder",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/78e016eeb0bf45d5bea47547128383a8/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/78e016eeb0bf45d5bea47547128383a8_lying_flat/20240826-222456_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBinder342MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="binder",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/a0026e7d1b244b9a9223daf4223c9372/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/a0026e7d1b244b9a9223daf4223c9372_lying_flat/20240826-212733_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBinder343MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="binder",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/a0026e7d1b244b9a9223daf4223c9372/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/a0026e7d1b244b9a9223daf4223c9372_lying_flat/20240826-215739_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBinder344MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="binder",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/a0026e7d1b244b9a9223daf4223c9372/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/a0026e7d1b244b9a9223daf4223c9372_lying_flat/20240826-220401_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBinder345MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="binder",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/a0026e7d1b244b9a9223daf4223c9372/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/a0026e7d1b244b9a9223daf4223c9372_lying_flat/20240826-212922_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBinder346MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="binder",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/a0026e7d1b244b9a9223daf4223c9372/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/a0026e7d1b244b9a9223daf4223c9372_lying_flat/20240826-221549_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBinder347MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="binder",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/a0026e7d1b244b9a9223daf4223c9372/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/a0026e7d1b244b9a9223daf4223c9372_lying_flat/20240826-211622_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatEraser439MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="eraser",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f0916a69ba514ecc973b44528b9dcc43/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f0916a69ba514ecc973b44528b9dcc43_lying_flat/20240826-212858_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatEraser440MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="eraser",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f0916a69ba514ecc973b44528b9dcc43/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f0916a69ba514ecc973b44528b9dcc43_lying_flat/20240826-211409_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatEraser441MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="eraser",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f0916a69ba514ecc973b44528b9dcc43/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f0916a69ba514ecc973b44528b9dcc43_lying_flat/20240826-222559_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatEraser442MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="eraser",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f0916a69ba514ecc973b44528b9dcc43/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f0916a69ba514ecc973b44528b9dcc43_lying_flat/20240826-222728_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatEraser443MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="eraser",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f0916a69ba514ecc973b44528b9dcc43/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f0916a69ba514ecc973b44528b9dcc43_lying_flat/20240826-213921_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatEraser444MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="eraser",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f0916a69ba514ecc973b44528b9dcc43/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f0916a69ba514ecc973b44528b9dcc43_lying_flat/20240826-215524_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBook451MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="book",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/2a371c84c5454f7facba7bb2f5312ad6/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/2a371c84c5454f7facba7bb2f5312ad6_lying_flat/20240826-215113_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBook452MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="book",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/2a371c84c5454f7facba7bb2f5312ad6/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/2a371c84c5454f7facba7bb2f5312ad6_lying_flat/20240826-213512_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBook453MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="book",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/2a371c84c5454f7facba7bb2f5312ad6/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/2a371c84c5454f7facba7bb2f5312ad6_lying_flat/20240826-212349_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBook454MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="book",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/2a371c84c5454f7facba7bb2f5312ad6/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/2a371c84c5454f7facba7bb2f5312ad6_lying_flat/20240826-212944_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBook455MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="book",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/2a371c84c5454f7facba7bb2f5312ad6/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/2a371c84c5454f7facba7bb2f5312ad6_lying_flat/20240826-211817_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBook456MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="book",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/2a371c84c5454f7facba7bb2f5312ad6/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/2a371c84c5454f7facba7bb2f5312ad6_lying_flat/20240826-222548_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBook457MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="book",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/2a371c84c5454f7facba7bb2f5312ad6/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/2a371c84c5454f7facba7bb2f5312ad6_lying_flat/20240826-213749_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBook514MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="book",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/c61227cac7224b86b43c53ac2a2b6ec7/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/c61227cac7224b86b43c53ac2a2b6ec7_lying_flat/20240826-222946_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBook515MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="book",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/c61227cac7224b86b43c53ac2a2b6ec7/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/c61227cac7224b86b43c53ac2a2b6ec7_lying_flat/20240826-211553_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBook516MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="book",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/c61227cac7224b86b43c53ac2a2b6ec7/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/c61227cac7224b86b43c53ac2a2b6ec7_lying_flat/20240826-220640_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBook517MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="book",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/c61227cac7224b86b43c53ac2a2b6ec7/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/c61227cac7224b86b43c53ac2a2b6ec7_lying_flat/20240826-222712_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBook518MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="book",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/c61227cac7224b86b43c53ac2a2b6ec7/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/c61227cac7224b86b43c53ac2a2b6ec7_lying_flat/20240826-221655_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBook519MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="book",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/c61227cac7224b86b43c53ac2a2b6ec7/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/c61227cac7224b86b43c53ac2a2b6ec7_lying_flat/20240826-222701_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBook955MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="book",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/b2d30398ba3741da9f9aef2319ee2b8b/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/b2d30398ba3741da9f9aef2319ee2b8b_lying_flat/20240826-212031_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBook956MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="book",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/b2d30398ba3741da9f9aef2319ee2b8b/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/b2d30398ba3741da9f9aef2319ee2b8b_lying_flat/20240826-215025_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBook957MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="book",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/b2d30398ba3741da9f9aef2319ee2b8b/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/b2d30398ba3741da9f9aef2319ee2b8b_lying_flat/20240826-213056_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBook958MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="book",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/b2d30398ba3741da9f9aef2319ee2b8b/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/b2d30398ba3741da9f9aef2319ee2b8b_lying_flat/20240826-214054_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBook959MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="book",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/b2d30398ba3741da9f9aef2319ee2b8b/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/b2d30398ba3741da9f9aef2319ee2b8b_lying_flat/20240826-213726_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBook960MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="book",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/b2d30398ba3741da9f9aef2319ee2b8b/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/b2d30398ba3741da9f9aef2319ee2b8b_lying_flat/20240826-220107_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatHardDrive1226MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="hard drive",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/e32b159011544b8aa7cacd812636353e/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/e32b159011544b8aa7cacd812636353e_lying_flat/20240826-213023_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatHardDrive1227MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="hard drive",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/e32b159011544b8aa7cacd812636353e/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/e32b159011544b8aa7cacd812636353e_lying_flat/20240826-212616_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatHardDrive1228MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="hard drive",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/e32b159011544b8aa7cacd812636353e/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/e32b159011544b8aa7cacd812636353e_lying_flat/20240826-212929_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatHardDrive1229MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="hard drive",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/e32b159011544b8aa7cacd812636353e/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/e32b159011544b8aa7cacd812636353e_lying_flat/20240826-211706_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatHardDrive1230MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="hard drive",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/e32b159011544b8aa7cacd812636353e/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/e32b159011544b8aa7cacd812636353e_lying_flat/20240826-212749_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatHardDrive1231MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="hard drive",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/e32b159011544b8aa7cacd812636353e/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/e32b159011544b8aa7cacd812636353e_lying_flat/20240826-212347_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBook1353MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="book",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/de79a920c48745ff95c0df7a7c300091/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/de79a920c48745ff95c0df7a7c300091_lying_flat/20240826-221309_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBook1354MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="book",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/de79a920c48745ff95c0df7a7c300091/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/de79a920c48745ff95c0df7a7c300091_lying_flat/20240826-220427_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBook1355MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="book",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/de79a920c48745ff95c0df7a7c300091/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/de79a920c48745ff95c0df7a7c300091_lying_flat/20240826-214244_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBook1356MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="book",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/de79a920c48745ff95c0df7a7c300091/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/de79a920c48745ff95c0df7a7c300091_lying_flat/20240826-211316_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBook1357MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="book",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/de79a920c48745ff95c0df7a7c300091/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/de79a920c48745ff95c0df7a7c300091_lying_flat/20240826-220041_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotLyingFlatBook1358MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="book",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/de79a920c48745ff95c0df7a7c300091/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/de79a920c48745ff95c0df7a7c300091_lying_flat/20240826-212300_no_interaction/trajectory-unified_wo_traj_v2.pkl"



from metasim.cfg.objects import PrimitiveCubeMetaCfg, RigidObjMetaCfg
from metasim.cfg.tasks.base_task_metacfg import BaseTaskMetaCfg
from metasim.constants import BenchmarkType, PhysicStateType, TaskType
from metasim.utils import configclass


@configclass
class OpensdorRotClaspRightWallet532MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="wallet",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/ccfcc4ae6efa44a2ba34c4c479be7daf/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/ccfcc4ae6efa44a2ba34c4c479be7daf_clasp_right/20240826-213156_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotClaspRightWallet533MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="wallet",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/ccfcc4ae6efa44a2ba34c4c479be7daf/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/ccfcc4ae6efa44a2ba34c4c479be7daf_clasp_right/20240826-215915_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotClaspRightWallet534MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="wallet",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/ccfcc4ae6efa44a2ba34c4c479be7daf/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/ccfcc4ae6efa44a2ba34c4c479be7daf_clasp_right/20240826-215743_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotClaspRightWallet535MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="wallet",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/ccfcc4ae6efa44a2ba34c4c479be7daf/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/ccfcc4ae6efa44a2ba34c4c479be7daf_clasp_right/20240826-212142_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotClaspRightWallet536MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="wallet",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/ccfcc4ae6efa44a2ba34c4c479be7daf/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/ccfcc4ae6efa44a2ba34c4c479be7daf_clasp_right/20240826-213901_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotClaspRightWallet537MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="wallet",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/ccfcc4ae6efa44a2ba34c4c479be7daf/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/ccfcc4ae6efa44a2ba34c4c479be7daf_clasp_right/20240826-213845_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotClaspRightWallet808MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="wallet",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f47fdcf9615d4e94a71e6731242a4c94/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f47fdcf9615d4e94a71e6731242a4c94_clasp_right/20240826-213903_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotClaspRightWallet809MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="wallet",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f47fdcf9615d4e94a71e6731242a4c94/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f47fdcf9615d4e94a71e6731242a4c94_clasp_right/20240826-215234_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotClaspRightWallet810MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="wallet",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f47fdcf9615d4e94a71e6731242a4c94/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f47fdcf9615d4e94a71e6731242a4c94_clasp_right/20240826-215345_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotClaspRightWallet811MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="wallet",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f47fdcf9615d4e94a71e6731242a4c94/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f47fdcf9615d4e94a71e6731242a4c94_clasp_right/20240826-213615_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotClaspRightWallet812MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="wallet",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f47fdcf9615d4e94a71e6731242a4c94/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f47fdcf9615d4e94a71e6731242a4c94_clasp_right/20240826-214257_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotClaspRightWallet813MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="wallet",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f47fdcf9615d4e94a71e6731242a4c94/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f47fdcf9615d4e94a71e6731242a4c94_clasp_right/20240826-215420_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotClaspRightWallet1044MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="wallet",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/dbb07d13a33546f09ac8ca98b1ddef20/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/dbb07d13a33546f09ac8ca98b1ddef20_clasp_right/20240826-213639_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotClaspRightWallet1045MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="wallet",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/dbb07d13a33546f09ac8ca98b1ddef20/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/dbb07d13a33546f09ac8ca98b1ddef20_clasp_right/20240826-211530_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotClaspRightWallet1046MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="wallet",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/dbb07d13a33546f09ac8ca98b1ddef20/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/dbb07d13a33546f09ac8ca98b1ddef20_clasp_right/20240826-215856_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotClaspRightWallet1047MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="wallet",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/dbb07d13a33546f09ac8ca98b1ddef20/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/dbb07d13a33546f09ac8ca98b1ddef20_clasp_right/20240826-221231_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotClaspRightWallet1048MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="wallet",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/dbb07d13a33546f09ac8ca98b1ddef20/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/dbb07d13a33546f09ac8ca98b1ddef20_clasp_right/20240826-221032_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotClaspRightWallet1049MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="wallet",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/dbb07d13a33546f09ac8ca98b1ddef20/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/dbb07d13a33546f09ac8ca98b1ddef20_clasp_right/20240826-212618_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotClaspRightWallet1050MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="wallet",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/dbb07d13a33546f09ac8ca98b1ddef20/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/dbb07d13a33546f09ac8ca98b1ddef20_clasp_right/20240826-220718_no_interaction/trajectory-unified_wo_traj_v2.pkl"



from __future__ import annotations

import argparse
import os
import sys
import time

import pygame
import rootutils
from curobo.types.math import Pose
from loguru import logger as log
from rich.logging import RichHandler

rootutils.setup_root(__file__, pythonpath=True)
log.configure(handlers=[{"sink": RichHandler(), "format": "{message}"}])
from pytorch3d import transforms

from metasim.cfg.scenario import ScenarioMetaCfg
from metasim.utils.kinematics_utils import get_curobo_models
from metasim.utils.teleop_utils import PygameKeyboardClient, process_kb_input


def parse_args():
    parser = argparse.ArgumentParser()
    parser.add_argument("--task", type=str, required=True)
    parser.add_argument("--robot", type=str, default="franka")
    parser.add_argument("--num_envs", type=int, default=1, help="Number of environments to simulate.")
    parser.add_argument(
        "--sim",
        type=str,
        default="isaaclab",
        choices=["isaaclab", "isaacgym", "pyrep", "pybullet", "sapien", "mujoco"],
    )
    parser.add_argument(
        "--render",
        type=str,
        choices=["isaaclab", "isaacgym", "pyrep", "pybullet", "sapien", "mujoco"],
    )
    args = parser.parse_args()
    return args


def main():
    args = parse_args()
    num_envs: int = args.num_envs

    # specificly for isaacgym
    if args.sim == "isaacgym":
        from isaacgym import gymapi, gymtorch, gymutil  # noqa: F401

    ## Import put here to support isaacgym

    import torch

    device = "cuda:0"

    from metasim.cfg.cameras import PinholeCameraMetaCfg
    from metasim.constants import SimType
    from metasim.double_sim import DoubleSimEnv
    from metasim.utils.demo_util import get_traj
    from metasim.utils.setup_util import get_robot, get_sim_env_class, get_task

    task = get_task(args.task)
    robot = get_robot(args.robot)
    camera = PinholeCameraMetaCfg(
        name="camera",
        data_types=["rgb", "depth"],
        width=256,
        height=256,
        pos=(1.5, 0.0, 1.5),
        look_at=(0.0, 0.0, 0.0),
    )
    scenario = ScenarioMetaCfg(task=task, robot=robot, cameras=[camera])

    tic = time.time()
    if args.render is None:
        env_class = get_sim_env_class(SimType(args.sim))
        env = env_class(scenario, num_envs)
    else:
        # print(args.sim, args.render)
        env_class_render = get_sim_env_class(SimType(args.render))
        env_render = env_class_render(scenario, num_envs)
        env_class_physics = get_sim_env_class(SimType(args.sim))
        env_physics = env_class_physics(scenario, num_envs)
        env = DoubleSimEnv(env_physics, env_render)
    toc = time.time()
    log.trace(f"Time to launch: {toc - tic:.2f}s")

    # data
    tic = time.time()
    assert os.path.exists(task.traj_filepath), f"Trajectory file: {task.traj_filepath} does not exist."
    init_states, all_actions, all_states = get_traj(task, robot, env.handler)
    toc = time.time()
    log.trace(f"Time to load data: {toc - tic:.2f}s")

    # reset before first step
    tic = time.time()
    obs, extras = env.reset(states=init_states[:num_envs])
    toc = time.time()
    log.trace(f"Time to reset: {toc - tic:.2f}s")

    # cuRobo IKSysFont()
    *_, robot_ik = get_curobo_models(robot)
    curobo_n_dof = len(robot_ik.robot_config.cspace.joint_names)
    ee_n_dof = len(robot.gripper_release_q)

    keyboard_client = PygameKeyboardClient(width=670, height=870, title="Keyboard Control")
    gripper_actuate_tensor = torch.tensor(robot.gripper_actuate_q, dtype=torch.float32, device=device)
    gripper_release_tensor = torch.tensor(robot.gripper_release_q, dtype=torch.float32, device=device)

    for line, instruction in enumerate(keyboard_client.instructions):
        log.info(f"{line:2d}: {instruction}")

    step = 0
    running = True
    while running:
        # update keyboard events every frame
        running = keyboard_client.update()
        if not running:
            break

        if keyboard_client.is_pressed(pygame.K_ESCAPE):
            log.debug("Exiting simulation...")
            running = False
            break

        keyboard_client.draw_instructions()

        obs = env.handler.get_observation()

        # compute target
        curr_robot_q = obs["joint_qpos"].cuda()
        robot_ee_state = obs["robot_ee_state"].cuda()
        robot_root_state = obs["robot_root_state"].cuda()
        robot_pos, robot_quat = robot_root_state[:, 0:3], robot_root_state[:, 3:7]
        curr_ee_pos, curr_ee_quat = robot_ee_state[:, 0:3], robot_ee_state[:, 3:7]

        curr_ee_pos = transforms.quaternion_apply(transforms.quaternion_invert(robot_quat), curr_ee_pos - robot_pos)
        curr_ee_quat_local = transforms.quaternion_multiply(transforms.quaternion_invert(robot_quat), curr_ee_quat)

        d_pos, d_rot_local, close_gripper = process_kb_input(keyboard_client, dpos=0.01, drot=0.05)
        d_pos_tensor = torch.tensor(d_pos, dtype=torch.float32, device=device)
        d_rot_tensor = torch.tensor(d_rot_local, dtype=torch.float32, device=device)
        gripper_q = gripper_actuate_tensor if close_gripper else gripper_release_tensor
        # delta quaternion
        d_rot_mat_local = transforms.euler_angles_to_matrix(d_rot_tensor.unsqueeze(0), "XYZ")
        d_quat_local = transforms.matrix_to_quaternion(d_rot_mat_local)[0]  # (4,)
        ee_pos_target = curr_ee_pos + d_pos_tensor
        ee_quat_target_local = transforms.quaternion_multiply(curr_ee_quat_local, d_quat_local)

        seed_config = curr_robot_q[:, :curobo_n_dof].unsqueeze(1).tile([1, robot_ik._num_seeds, 1])
        result = robot_ik.solve_batch(
            Pose(ee_pos_target.unsqueeze(0), ee_quat_target_local.unsqueeze(0)), seed_config=seed_config
        )

        ik_succ = result.success.squeeze(1)
        q = curr_robot_q.clone()  # shape: [num_envs, robot.num_joints]
        q[ik_succ, :curobo_n_dof] = result.solution[ik_succ, 0].clone()
        q[:, -ee_n_dof:] = gripper_q

        # XXX: this may not work for all simulators, since the order of joints may be different
        actions = [
            {"dof_pos_target": dict(zip(robot.joint_limits.keys(), q[i_env].tolist()))} for i_env in range(num_envs)
        ]
        env.handler.step(actions)
        env.handler.render()

        step += 1
        log.debug(f"Step {step}")

    keyboard_client.close()
    env.handler.close()
    sys.exit()


if __name__ == "__main__":
    main()
